@@ -181,7 +181,13 @@ def _sample_daughter_diameters(section, params, params_tree, rng=np.random):
     # pylint: disable=too-many-locals
     major_sections = params_tree["major_sections"]
 
-    apply_asymmetry = section.id in major_sections
+    apply_asymmetry = False
+    if params_tree.get("with_asymmetry", False):
+        child_not_in_major = [child.id not in major_sections for child in section.children]
+        # if children are not asymmetrical, don't apply asymmetry
+        if False in child_not_in_major:
+            child_sort = np.argsort(child_not_in_major)
+            apply_asymmetry = True
 
     reduction_factor = params_tree["reduction_factor_max"] + 1.0
     # try until we get a reduction of diameter in the branching
@@ -218,15 +224,8 @@ def _sample_daughter_diameters(section, params, params_tree, rng=np.random):
 
     diams = [diam_1] + (len(section.children) - 1) * [diam_2]
 
-    if params_tree.get("with_asymmetry", False):
-        # This case should always happen since the `with_asymmetry` attribute is always set to True
-        # in `_select_model`
-
-        # returns child diameters sorted by child length (major/secondary for apical tree)
-        child_not_in_major = [child.id not in major_sections for child in section.children]
-        if False in child_not_in_major:
-            child_sort = np.argsort(child_not_in_major)
-            return list(np.array(diams)[child_sort])
+    if apply_asymmetry:
+        return list(np.array(diams)[child_sort])
 
     # At the moment we don't have enough information to do better than a random choice in this case
     rng.shuffle(diams)
@@ -240,7 +239,7 @@ def _diametrize_section(section, initial_diam, taper, min_diam=0.07, max_diam=10
         section (morphio.Section): current section.
         initial_diam (float): initial diameter.
         taper (float): taper rate.
-        min_diam (flaot): minimum diameter.
+        min_diam (float): minimum diameter.
         max_diam (float): maximum diameter.
     """
     diams = polynomial.polyval(morph_functions.lengths_from_origin(section), [initial_diam, taper])
@@ -397,30 +396,37 @@ def _select_model(model):
     return partial(_diametrize_neuron, params_tree)
 
 
-def build(neuron, model_params, neurite_types, config, rng=np.random):
+def build(neuron, neurite_types, model_params, diam_params, random_generator=np.random):
     """Builder function for generating diameters of a neuron from the a diameter models.
 
     Args:
         neuron (morphio.mut.Morphology): neuron to diametrize.
+        neurite_types (list[str] or str or list[SectionType] or SectionType): the neurite type(s)
+            to consider.
         model_params (dict): model parameters.
-        neurite_types (str): the neurite type to consider.
-        config (dict): general configuration parameters.
-        rng (numpy.random.Generator): the random number generator to use.
+        diam_params (dict): general configuration parameters.
+        random_generator (numpy.random.Generator): the random number generator to use.
     """
-    if "seed" in config:
-        np.random.seed(config["seed"])
+    if isinstance(neurite_types, (str, SectionType)):
+        neurite_types = [neurite_types]
+
+    if "seed" in diam_params:
+        random_generator = np.random.default_rng(diam_params["seed"])
+
     _reset_caches()
 
-    if len(config["models"]) > 1:
+    if len(diam_params["models"]) > 1:
         L.warning("Several models provided, we will only use the first")
-    diameter_generator = _select_model(config["models"][0])
+    diameter_generator = _select_model(diam_params["models"][0])
 
-    diameter_generator(neuron, model_params, neurite_types, config, rng=rng)
-    n_samples = config.get("n_samples", 1)
+    diameter_generator(neuron, model_params, neurite_types, diam_params, rng=random_generator)
+    n_samples = diam_params.get("n_samples", 1)
     if n_samples > 1:
         diameters = utils.get_all_diameters(neuron)
         for _ in range(n_samples - 1):
-            diameter_generator(neuron, model_params, neurite_types, config, rng=rng)
+            diameter_generator(
+                neuron, model_params, neurite_types, diam_params, rng=random_generator
+            )
             for i, new_diams in enumerate(utils.get_all_diameters(neuron)):
                 diameters[i] += new_diams
         for i, _ in enumerate(diameters):
@@ -472,7 +478,7 @@ def _set_first_diams(morphology, diams, length):
 def diametrize_axon(
     morphology,
     main_diameter=1.0,
-    colateral_diameter=0.1,
+    collateral_diameter=0.1,
     main_taper=-0.0005,
     axon_point_isec=None,
     ais_length=60,
@@ -483,14 +489,14 @@ def diametrize_axon(
     The main axon branch (from soma to axon point) will have a tapered diameter, and the
     colaterals a constant diameter.
 
-    If an axon point is not provided, and main_diameter > colateral_diameter, the diameters will
+    If an axon point is not provided, and main_diameter > collateral_diameter, the diameters will
     decrease with taper and bifurcations, with hardcoded parameters sibling_ratio = 0.5 and
     diameter_power_relation = 0.5.
 
     Args:
         morphology (morphio.mut.Morphology): morphology to diametrize.
         main_diameter (float): diameter of main axon branch (from soma to `axon_point_isec`).
-        colateral_diameter (float): diameter of colateral branches.
+        collateral_diameter (float): diameter of collateral branches.
         main_taper (float): taper rate of main branch (set to 0 for no taper, should be negative).
         axon_point_isec (int): morphio section id of axon point (see :mod:`morph_tool.axon_point`
             module).
@@ -507,7 +513,7 @@ def diametrize_axon(
         "terminal_diameters": {
             "axon": {
                 "distribution": "constant",
-                "params": {"value": colateral_diameter, "max": main_diameter},
+                "params": {"value": collateral_diameter, "max": main_diameter},
             }
         },
         "tapers": {
@@ -535,5 +541,5 @@ def diametrize_axon(
     config = {"models": ["generic"], "trunk_max_tries": 1, "n_samples": 1}
 
     diams = _save_first_diams(morphology, ais_length)
-    build(morphology, model_params, neurite_types=["axon"], config=config, rng=rng)
+    build(morphology, "axon", model_params, diam_params=config, random_generator=rng)
     _set_first_diams(morphology, diams, ais_length)
